==> netjfwatcher1.3.5_ApacheDerby.tar.gz: netjfwatcher/engine/socket/info/DatabasePropertyInfoList.java <==
/*
 * Created on 2004/06/05
 *
 *
 * Copyright(c) 2004 Yoshimasa Matsumoto
 */
package netjfwatcher.engine.socket.info;

import java.io.Serializable;
import java.util.ArrayList;


/**
 * ef[^x[X̃vpeB\[Xt@CǂݍŃXgƂĕێNXłB
 *
 * f[^x[X̃vpeBiDatabasePropertyInfoj
 * Ef[^x[X
 * Ef[^x[XhCo
 * Ef[^x[XڑURL
 * E[U[
 * EpX[h
 *
 * @author Yoshimasa Matsumoto
 * @version 1.0
 */
public class DatabasePropertyInfoList implements Serializable {
    /**
         * serialVersionUID
         */
    private static final long serialVersionUID = 2252287855145512800L;

    /* f[^x[XvpeBXg */
    private ArrayList databasePropList = new ArrayList();

    /**
     * ẽf[^x[XvpeBXgƂĕێ܂B
     *
     * @param databaseProp f[^x[XvpeB
     */
    public void setDatabasePropList(DatabasePropertyInfo databaseProp) {
        databasePropList.add(databaseProp);
    }

    /**
     * GW̃f[^x[XvpeBXg當zɕϊĕԂ܂B
     *
     * @return f[^x[XvpeBXgz
     */
    public DatabasePropertyInfo[] getDatabasePropInfoList() {
        DatabasePropertyInfo[] databaseProp =
            new DatabasePropertyInfo[databasePropList.size()];

        for (int i = 0; i < databasePropList.size(); i++) {
            databaseProp[i] = (DatabasePropertyInfo) databasePropList.get(i);
        }

        return databaseProp;
    }

    /**
     * f[^x[XvpeBXgԂ܂B
     *
     * @return databasePropList f[^x[XvpeBXg
     */
    public ArrayList getDatabasePropList() {
        return databasePropList;
    }

    /**
     * f[^x[XvpeBXgZbg܂B
     *
     * @param list f[^x[XvpeBXg
     */
    public void setDatabasePropList(ArrayList list) {
        databasePropList = list;
    }
}

==> netjfwatcher1.3.7_ApacheDerby.tar.gz: netjfwatcher/engine/socket/info/DatabasePropertyInfoList.java <==
/*
 * Created on 2004/06/05
 *
 *
 * Copyright(c) 2004 Yoshimasa Matsumoto
 */
package netjfwatcher.engine.socket.info;

import java.io.Serializable;
import java.util.ArrayList;


/**
 * ef[^x[X̃vpeB\[Xt@CǂݍŃXgƂĕێNXłB
 *
 * f[^x[X̃vpeBiDatabasePropertyInfoj
 * Ef[^x[X
 * Ef[^x[XhCo
 * Ef[^x[XڑURL
 * E[U[
 * EpX[h
 *
 * @author Yoshimasa Matsumoto
 * @version 1.0
 */
public class DatabasePropertyInfoList implements Serializable {
    /*
     * serialVersionUID
     */
    private static final long serialVersionUID = 2252287855145512800L;

    /* f[^x[XvpeBXg */
    private ArrayList<DatabasePropertyInfo> databasePropList = new ArrayList<DatabasePropertyInfo>();

    /**
     * ẽf[^x[XvpeBXgƂĕێ܂B
     *
     * @param databaseProp f[^x[XvpeB
     */
    public void setDatabasePropList(DatabasePropertyInfo databaseProp) {
        databasePropList.add(databaseProp);
    }

    /**
     * GW̃f[^x[XvpeBXg當zɕϊĕԂ܂B
     *
     * @return f[^x[XvpeBXgz
     */
    public DatabasePropertyInfo[] getDatabasePropInfoList() {
        DatabasePropertyInfo[] databaseProp =
            new DatabasePropertyInfo[databasePropList.size()];

        for (int i = 0; i < databasePropList.size(); i++) {
            databaseProp[i] = (DatabasePropertyInfo) databasePropList.get(i);
        }

        return databaseProp;
    }

    /**
     * f[^x[XvpeBXgԂ܂B
     *
     * @return databasePropList f[^x[XvpeBXg
     */
    public ArrayList getDatabasePropList() {
        return databasePropList;
    }

    /**
     * f[^x[XvpeBXgZbg܂B
     *
     * @param list f[^x[XvpeBXg
     */
    public void setDatabasePropList(ArrayList list) {
        databasePropList = list;
    }
}
